.onLoad <- function(libname, pkgname) {
  extdata_dirpath <- system.file("extdata", package=pkgname,
                                 lib.loc=libname, mustWork=TRUE)

  ## fetch the metadata from the smallest file to minimize loading time
  finfo <- file.info(list.files(pattern=sprintf("%s.RLEnonsnv", pkgname), path=extdata_dirpath,
                                full.names=TRUE))

  obj <- readRDS(file.path(extdata_dirpath, basename(rownames(finfo)[which.min(finfo$size)])))
  mdobj <- metadata(obj)
  stopifnot(identical(pkgname, mdobj$data_pkgname)) ## QC

  serializedobjs <- rownames(finfo)
  names(serializedobjs) <- serializedobjs

  ## Make and export MafDb object.
  mafobj <- MafDb(provider=mdobj$provider,
                  provider_version=mdobj$provider_version,
                  download_url=mdobj$download_url,
                  download_date=mdobj$download_date,
                  reference_genome=mdobj$reference_genome,
                  data_pkgname=pkgname,
                  data_dirpath=extdata_dirpath,
                  data_serialized_objnames=serializedobjs,
                  data_tag="ESP")

  ns <- asNamespace(pkgname)
  assign(pkgname, mafobj, envir=ns)

  namespaceExport(ns, pkgname)
}
